==> hs-xmonad-contrib-0.11.1p1.tgz: lib/ghc/xmonad-contrib-0.11.1/register.sh <==
#!/bin/sh
echo 'name: xmonad-contrib
version: 0.11.1
id: xmonad-contrib-0.11.1-be9730211610031cf7c82c803edc42e6

license: BSD3
copyright:
maintainer: xmonad@haskell.org
stability:
homepage: http://xmonad.org/
package-url:
synopsis: Third party extensions for xmonad
description: Third party tiling algorithms, configurations and scripts to xmonad,
             a tiling window manager for X.
             .
             For an introduction to building, configuring and using xmonad
             extensions, see "XMonad.Doc". In particular:
             .
             "XMonad.Doc.Configuring", a guide to configuring xmonad
             .
             "XMonad.Doc.Extending", using the contributed extensions library
             .
             "XMonad.Doc.Developing", introduction to xmonad internals and writing
             your own extensions.
             .
category: System
author: Spencer Janssen & others
pkgpath: x11/hs-xmonad-contrib
exposed: True
exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                 XMonad.Doc.Extending XMonad.Doc.Developing
                 XMonad.Actions.BluetileCommands XMonad.Actions.Commands
                 XMonad.Actions.ConstrainedResize XMonad.Actions.CopyWindow
                 XMonad.Actions.CycleRecentWS XMonad.Actions.CycleSelectedLayouts
                 XMonad.Actions.CycleWindows XMonad.Actions.CycleWS
                 XMonad.Actions.DeManage XMonad.Actions.DwmPromote
                 XMonad.Actions.DynamicWorkspaces
                 XMonad.Actions.DynamicWorkspaceGroups
                 XMonad.Actions.DynamicWorkspaceOrder
                 XMonad.Actions.FindEmptyWorkspace XMonad.Actions.FlexibleManipulate
                 XMonad.Actions.FlexibleResize XMonad.Actions.FloatKeys
                 XMonad.Actions.FloatSnap XMonad.Actions.FocusNth
                 XMonad.Actions.GridSelect XMonad.Actions.GroupNavigation
                 XMonad.Actions.Launcher XMonad.Actions.MessageFeedback
                 XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
                 XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
                 XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
                 XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
                 XMonad.Actions.Promote XMonad.Actions.RandomBackground
                 XMonad.Actions.KeyRemap XMonad.Actions.RotSlaves
                 XMonad.Actions.Search XMonad.Actions.ShowText
                 XMonad.Actions.SimpleDate XMonad.Actions.SinkAll
                 XMonad.Actions.SpawnOn XMonad.Actions.Submap
                 XMonad.Actions.SwapWorkspaces XMonad.Actions.TagWindows
                 XMonad.Actions.TopicSpace XMonad.Actions.UpdateFocus
                 XMonad.Actions.UpdatePointer XMonad.Actions.Warp
                 XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
                 XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
                 XMonad.Actions.WithAll XMonad.Actions.WorkspaceCursors
                 XMonad.Actions.WorkspaceNames XMonad.Actions.Workscreen
                 XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bluetile
                 XMonad.Config.Desktop XMonad.Config.Droundy XMonad.Config.Gnome
                 XMonad.Config.Kde XMonad.Config.Sjanssen XMonad.Config.Xfce
                 XMonad.Hooks.CurrentWorkspaceOnTop XMonad.Hooks.DebugEvents
                 XMonad.Hooks.DebugKeyEvents XMonad.Hooks.DynamicBars
                 XMonad.Hooks.DynamicHooks XMonad.Hooks.DynamicLog
                 XMonad.Hooks.DebugStack XMonad.Hooks.EwmhDesktops
                 XMonad.Hooks.FadeInactive XMonad.Hooks.FadeWindows
                 XMonad.Hooks.FloatNext XMonad.Hooks.ICCCMFocus
                 XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDocks
                 XMonad.Hooks.ManageHelpers XMonad.Hooks.Minimize XMonad.Hooks.Place
                 XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RestoreMinimized
                 XMonad.Hooks.ScreenCorners XMonad.Hooks.Script
                 XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
                 XMonad.Hooks.ToggleHook XMonad.Hooks.UrgencyHook
                 XMonad.Hooks.WorkspaceByPos XMonad.Hooks.XPropManage
                 XMonad.Layout.Accordion XMonad.Layout.AutoMaster
                 XMonad.Layout.BorderResize XMonad.Layout.BoringWindows
                 XMonad.Layout.ButtonDecoration XMonad.Layout.CenteredMaster
                 XMonad.Layout.Circle XMonad.Layout.Column XMonad.Layout.Combo
                 XMonad.Layout.ComboP XMonad.Layout.Cross XMonad.Layout.Decoration
                 XMonad.Layout.DecorationAddons XMonad.Layout.DecorationMadness
                 XMonad.Layout.Dishes XMonad.Layout.DraggingVisualizer
                 XMonad.Layout.DragPane XMonad.Layout.Drawer XMonad.Layout.DwmStyle
                 XMonad.Layout.FixedColumn XMonad.Layout.Fullscreen
                 XMonad.Layout.Gaps XMonad.Layout.Grid XMonad.Layout.GridVariants
                 XMonad.Layout.Groups XMonad.Layout.Groups.Examples
                 XMonad.Layout.Groups.Helpers XMonad.Layout.Groups.Wmii
                 XMonad.Layout.HintedGrid XMonad.Layout.HintedTile XMonad.Layout.IM
                 XMonad.Layout.ImageButtonDecoration
                 XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
                 XMonad.Layout.LayoutBuilderP XMonad.Layout.LayoutCombinators
                 XMonad.Layout.LayoutHints XMonad.Layout.LayoutModifier
                 XMonad.Layout.LayoutScreens XMonad.Layout.LimitWindows
                 XMonad.Layout.MagicFocus XMonad.Layout.Magnifier
                 XMonad.Layout.Master XMonad.Layout.Maximize
                 XMonad.Layout.MessageControl XMonad.Layout.Minimize
                 XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
                 XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
                 XMonad.Layout.MultiToggle XMonad.Layout.MultiToggle.Instances
                 XMonad.Layout.Named XMonad.Layout.NoBorders
                 XMonad.Layout.NoFrillsDecoration XMonad.Layout.OnHost
                 XMonad.Layout.OneBig XMonad.Layout.PerWorkspace
                 XMonad.Layout.PositionStoreFloat XMonad.Layout.Reflect
                 XMonad.Layout.Renamed XMonad.Layout.ResizableTile
                 XMonad.Layout.ResizeScreen XMonad.Layout.Roledex
                 XMonad.Layout.ShowWName XMonad.Layout.SimpleDecoration
                 XMonad.Layout.SimpleFloat XMonad.Layout.Simplest
                 XMonad.Layout.SimplestFloat XMonad.Layout.Spacing
                 XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
                 XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
                 XMonad.Layout.Tabbed XMonad.Layout.ThreeColumns
                 XMonad.Layout.ToggleLayouts XMonad.Layout.TrackFloating
                 XMonad.Layout.TwoPane XMonad.Layout.WindowArranger
                 XMonad.Layout.WindowNavigation
                 XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
                 XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppendFile
                 XMonad.Prompt.AppLauncher XMonad.Prompt.Directory
                 XMonad.Prompt.DirExec XMonad.Prompt.Email XMonad.Prompt.Input
                 XMonad.Prompt.Layout XMonad.Prompt.Man XMonad.Prompt.RunOrRaise
                 XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
                 XMonad.Prompt.Window XMonad.Prompt.Workspace XMonad.Prompt.XMonad
                 XMonad.Util.Cursor XMonad.Util.CustomKeys XMonad.Util.DebugWindow
                 XMonad.Util.Dmenu XMonad.Util.Dzen XMonad.Util.ExtensibleState
                 XMonad.Util.EZConfig XMonad.Util.Font XMonad.Util.Image
                 XMonad.Util.Invisible XMonad.Util.Loggers XMonad.Util.NamedActions
                 XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
                 XMonad.Util.Paste XMonad.Util.PositionStore XMonad.Util.Replace
                 XMonad.Util.Run XMonad.Util.Scratchpad XMonad.Util.SpawnOnce
                 XMonad.Util.Stack XMonad.Util.StringProp XMonad.Util.Themes
                 XMonad.Util.Timer XMonad.Util.Types XMonad.Util.WindowProperties
                 XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
                 XMonad.Util.XUtils
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11.1
library-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11.1
hs-libraries: HSxmonad-contrib-0.11.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: X11-1.6.1.1-4a4f242486ab0f5871a70bcb05fc9b64
         X11-xft-0.3.1-aad3a1a9e973718d34f37399334e9780
         base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
         directory-1.2.0.1-ee04c884b72040489d2e2ca6dd62e6ac
         extensible-exceptions-0.1.1.4-255a395b3b026cb94b23754e1c372785
         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
         old-locale-1.0.0.5-6729cb9d9cc62d150655de8fc5401b91
         old-time-1.1.0.1-029c40e673a46f6084b935f654a6fa28
         process-1.1.0.2-76e05340eb66705981411022731ca84a
         random-1.0.1.1-023a342365721422ffd5a919bc8708bb
         unix-2.6.0.1-2939d4be83b53d31ca104e0487b1ef98
         utf8-string-0.3.8-ac107fb901621046f538bc29451f9d70
         xmonad-0.11-06d49a013633b28f09c16abbbaf31abb
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-xmonad-contrib-0.11.1/html/xmonad-contrib.haddock
haddock-html: /usr/local/share/doc/hs-xmonad-contrib-0.11.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-xmonad-contrib-0.11.3.tgz: lib/ghc/xmonad-contrib-0.11.3/register.sh <==
#!/bin/sh
export PATH='/usr/obj/hs-xmonad-contrib-0.11.3/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: xmonad-contrib
version: 0.11.3
id: xmonad-contrib-0.11.3-b9b15329093cde349810cae680bc20f0

license: BSD3
copyright:
maintainer: xmonad@haskell.org
stability:
homepage: http://xmonad.org/
package-url:
synopsis: Third party extensions for xmonad
description: Third party tiling algorithms, configurations and scripts to xmonad,
             a tiling window manager for X.
             .
             For an introduction to building, configuring and using xmonad
             extensions, see "XMonad.Doc". In particular:
             .
             "XMonad.Doc.Configuring", a guide to configuring xmonad
             .
             "XMonad.Doc.Extending", using the contributed extensions library
             .
             "XMonad.Doc.Developing", introduction to xmonad internals and writing
             your own extensions.
             .
category: System
author: Spencer Janssen & others
pkgpath: x11/hs-xmonad-contrib
exposed: True
exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                 XMonad.Doc.Extending XMonad.Doc.Developing
                 XMonad.Actions.BluetileCommands XMonad.Actions.Commands
                 XMonad.Actions.ConstrainedResize XMonad.Actions.CopyWindow
                 XMonad.Actions.CycleRecentWS XMonad.Actions.CycleSelectedLayouts
                 XMonad.Actions.CycleWindows XMonad.Actions.CycleWS
                 XMonad.Actions.DeManage XMonad.Actions.DwmPromote
                 XMonad.Actions.DynamicWorkspaces
                 XMonad.Actions.DynamicWorkspaceGroups
                 XMonad.Actions.DynamicWorkspaceOrder
                 XMonad.Actions.FindEmptyWorkspace XMonad.Actions.FlexibleManipulate
                 XMonad.Actions.FlexibleResize XMonad.Actions.FloatKeys
                 XMonad.Actions.FloatSnap XMonad.Actions.FocusNth
                 XMonad.Actions.GridSelect XMonad.Actions.GroupNavigation
                 XMonad.Actions.Launcher XMonad.Actions.MessageFeedback
                 XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
                 XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
                 XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
                 XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
                 XMonad.Actions.Promote XMonad.Actions.RandomBackground
                 XMonad.Actions.KeyRemap XMonad.Actions.RotSlaves
                 XMonad.Actions.Search XMonad.Actions.ShowText
                 XMonad.Actions.SimpleDate XMonad.Actions.SinkAll
                 XMonad.Actions.SpawnOn XMonad.Actions.Submap
                 XMonad.Actions.SwapWorkspaces XMonad.Actions.TagWindows
                 XMonad.Actions.TopicSpace XMonad.Actions.UpdateFocus
                 XMonad.Actions.UpdatePointer XMonad.Actions.Warp
                 XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
                 XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
                 XMonad.Actions.WithAll XMonad.Actions.WorkspaceCursors
                 XMonad.Actions.WorkspaceNames XMonad.Actions.Workscreen
                 XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bluetile
                 XMonad.Config.Desktop XMonad.Config.Droundy XMonad.Config.Gnome
                 XMonad.Config.Kde XMonad.Config.Sjanssen XMonad.Config.Xfce
                 XMonad.Hooks.CurrentWorkspaceOnTop XMonad.Hooks.DebugEvents
                 XMonad.Hooks.DebugKeyEvents XMonad.Hooks.DynamicBars
                 XMonad.Hooks.DynamicHooks XMonad.Hooks.DynamicLog
                 XMonad.Hooks.DebugStack XMonad.Hooks.EwmhDesktops
                 XMonad.Hooks.FadeInactive XMonad.Hooks.FadeWindows
                 XMonad.Hooks.FloatNext XMonad.Hooks.ICCCMFocus
                 XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDocks
                 XMonad.Hooks.ManageHelpers XMonad.Hooks.Minimize XMonad.Hooks.Place
                 XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RestoreMinimized
                 XMonad.Hooks.ScreenCorners XMonad.Hooks.Script
                 XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
                 XMonad.Hooks.ToggleHook XMonad.Hooks.UrgencyHook
                 XMonad.Hooks.WorkspaceByPos XMonad.Hooks.XPropManage
                 XMonad.Layout.Accordion XMonad.Layout.AutoMaster
                 XMonad.Layout.BorderResize XMonad.Layout.BoringWindows
                 XMonad.Layout.ButtonDecoration XMonad.Layout.CenteredMaster
                 XMonad.Layout.Circle XMonad.Layout.Column XMonad.Layout.Combo
                 XMonad.Layout.ComboP XMonad.Layout.Cross XMonad.Layout.Decoration
                 XMonad.Layout.DecorationAddons XMonad.Layout.DecorationMadness
                 XMonad.Layout.Dishes XMonad.Layout.DraggingVisualizer
                 XMonad.Layout.DragPane XMonad.Layout.Drawer XMonad.Layout.DwmStyle
                 XMonad.Layout.FixedColumn XMonad.Layout.Fullscreen
                 XMonad.Layout.Gaps XMonad.Layout.Grid XMonad.Layout.GridVariants
                 XMonad.Layout.Groups XMonad.Layout.Groups.Examples
                 XMonad.Layout.Groups.Helpers XMonad.Layout.Groups.Wmii
                 XMonad.Layout.HintedGrid XMonad.Layout.HintedTile XMonad.Layout.IM
                 XMonad.Layout.ImageButtonDecoration
                 XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
                 XMonad.Layout.LayoutBuilderP XMonad.Layout.LayoutCombinators
                 XMonad.Layout.LayoutHints XMonad.Layout.LayoutModifier
                 XMonad.Layout.LayoutScreens XMonad.Layout.LimitWindows
                 XMonad.Layout.MagicFocus XMonad.Layout.Magnifier
                 XMonad.Layout.Master XMonad.Layout.Maximize
                 XMonad.Layout.MessageControl XMonad.Layout.Minimize
                 XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
                 XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
                 XMonad.Layout.MultiToggle XMonad.Layout.MultiToggle.Instances
                 XMonad.Layout.Named XMonad.Layout.NoBorders
                 XMonad.Layout.NoFrillsDecoration XMonad.Layout.OnHost
                 XMonad.Layout.OneBig XMonad.Layout.PerWorkspace
                 XMonad.Layout.PositionStoreFloat XMonad.Layout.Reflect
                 XMonad.Layout.Renamed XMonad.Layout.ResizableTile
                 XMonad.Layout.ResizeScreen XMonad.Layout.Roledex
                 XMonad.Layout.ShowWName XMonad.Layout.SimpleDecoration
                 XMonad.Layout.SimpleFloat XMonad.Layout.Simplest
                 XMonad.Layout.SimplestFloat XMonad.Layout.Spacing
                 XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
                 XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
                 XMonad.Layout.Tabbed XMonad.Layout.ThreeColumns
                 XMonad.Layout.ToggleLayouts XMonad.Layout.TrackFloating
                 XMonad.Layout.TwoPane XMonad.Layout.WindowArranger
                 XMonad.Layout.WindowNavigation
                 XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
                 XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppendFile
                 XMonad.Prompt.AppLauncher XMonad.Prompt.Directory
                 XMonad.Prompt.DirExec XMonad.Prompt.Email XMonad.Prompt.Input
                 XMonad.Prompt.Layout XMonad.Prompt.Man XMonad.Prompt.RunOrRaise
                 XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
                 XMonad.Prompt.Window XMonad.Prompt.Workspace XMonad.Prompt.XMonad
                 XMonad.Util.Cursor XMonad.Util.CustomKeys XMonad.Util.DebugWindow
                 XMonad.Util.Dmenu XMonad.Util.Dzen XMonad.Util.ExtensibleState
                 XMonad.Util.EZConfig XMonad.Util.Font XMonad.Util.Image
                 XMonad.Util.Invisible XMonad.Util.Loggers XMonad.Util.NamedActions
                 XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
                 XMonad.Util.Paste XMonad.Util.PositionStore XMonad.Util.Replace
                 XMonad.Util.Run XMonad.Util.Scratchpad XMonad.Util.SpawnOnce
                 XMonad.Util.Stack XMonad.Util.StringProp XMonad.Util.Themes
                 XMonad.Util.Timer XMonad.Util.Types XMonad.Util.WindowProperties
                 XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
                 XMonad.Util.XUtils
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11.3
library-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11.3
hs-libraries: HSxmonad-contrib-0.11.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: X11-1.6.1.1-3a65c01bb60e27391be7fb564fa7621e
         X11-xft-0.3.1-3069c0df2810aeaea56dcf8ce80f4e13
         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
         directory-1.2.1.0-255ee2a4a618c74613f025ccc4ecc082
         extensible-exceptions-0.1.1.4-ff00541964e8b4f6fe7adae94cd5f3b4
         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
         old-locale-1.0.0.6-50b0125c49f76af85dc7aa22975cdc34
         old-time-1.1.0.2-e3f776e97c1a6ff1770b04943a7ef7c6
         process-1.2.0.0-891670ec11c8b086a673596aa083f351
         random-1.0.1.1-18033e0e7d0ae09dc4f8adbdce56b966
         unix-2.7.0.1-49291e6beb52ca8844af5af8283d8383
         utf8-string-0.3.8-33d6cbdc649f1dd0048718c4b65b149b
         xmonad-0.11-8895dc78765dd76adca07ddb4db14c91
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-xmonad-contrib-0.11.3/html/xmonad-contrib.haddock
haddock-html: /usr/local/share/doc/hs-xmonad-contrib-0.11.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
